/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005-2006 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: MBeanNames.java,v 1.1 2007/06/11 13:34:07 lam Exp $
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.tools.rmi.common.serializable;

import java.io.Serializable;

import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;

/**
 * the MBeanNames implementation for RMI component.
 * @author nsalatge
 *
 */
public class MBeanNames implements javax.jbi.management.MBeanNames, Serializable {

    /**
     * the serialVersionUID.
     */
    private static final long serialVersionUID = -1832201538669181132L;

    /**
     * Custom name.
     */
    private static final String CUSTOM = "custom";

    /**
     * the domain.
     */
    private String domain;

    /**
     * Constructs the MBeanNames with the specified domain name. This domain
     * name will be used for creating mBean names.
     *
     * @param domain
     *            the domain
     */
    public MBeanNames(final String domain) {
        this.domain = domain;
    }

    /**
     * @see javax.jbi.management.MBeanNames#createCustomComponentMBeanName(String
     *      customName)
     * @param customName
     *          the customName
     * @return
     *        the object name
     */
    public ObjectName createCustomComponentMBeanName(final String customName) {
        String type = MBeanNames.CUSTOM;
        String theType = null;
        if (type != null) {
            type =  "type=" + type + ",";
        } else {
            type = "";
        }
        String theName = "name=" + customName;
        ObjectName on = null;
        try {
            on = new ObjectName(this.domain + ":" + theType + theName);
        } catch (MalformedObjectNameException e) {
            throw new RuntimeException(e);
            // internal use, so exeception should never be thrown
        }
        return on;
    }

    /**
     * @see javax.jbi.management.MBeanNames#getJmxDomainName()
     * @return
     *     the domain
     */
    public String getJmxDomainName() {
        return this.domain;
    }
}


